"""Tag model flattening

Revision ID: d7725a4e500c
Revises: 1b49fefdfcb0
Create Date: 2022-09-01 16:18:42.355865

"""
import logging

import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "d7725a4e500c"
down_revision = "1b49fefdfcb0"
branch_labels = None
depends_on = None

logger = logging.getLogger("alembic")


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    # Make new tag table
    logger.info("This may take few minutes depending on the size of your database...")
    op.create_table(
        "tag_new",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("tag", sa.String(), nullable=False),
        sa.Column("object_id", sa.Integer(), nullable=False),
        sa.ForeignKeyConstraint(["object_id"], ["object.id"], ondelete="CASCADE"),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_index(
        "ix_object_new_tag_object_id", "tag_new", ["tag", "object_id"], unique=True
    )
    op.create_index(op.f("ix_tag_new_tag"), "tag_new", ["tag"], unique=False)
    op.create_index(
        op.f("ix_tag_new_object_id"), "tag_new", ["object_id"], unique=False
    )
    # Rewrite tag entries into new table
    op.execute(
        """
        INSERT INTO tag_new (tag, object_id)
        SELECT tag, object_id FROM object_tag JOIN tag ON tag.id = object_tag.tag_id;  
    """
    )
    # Remove old table
    op.drop_index("ix_tag_tag", table_name="tag")
    op.drop_index("ix_object_tag_object_child", table_name="object_tag")
    op.drop_index("ix_object_tag_object_id", table_name="object_tag")
    op.drop_index("ix_object_tag_tag_id", table_name="object_tag")
    op.drop_table("object_tag")
    op.drop_table("tag")
    # Rename new table and indices
    op.execute(
        "ALTER TABLE tag_new RENAME CONSTRAINT tag_new_object_id_fkey TO tag_object_id_fkey"
    )
    op.execute("ALTER TABLE tag_new RENAME CONSTRAINT tag_new_pkey TO tag_pkey")
    op.execute("ALTER TABLE tag_new RENAME TO tag")
    op.execute(
        "ALTER INDEX ix_object_new_tag_object_id RENAME TO ix_object_tag_object_id"
    )
    op.execute("ALTER INDEX ix_tag_new_tag RENAME TO ix_tag_tag")
    op.execute("ALTER INDEX ix_tag_new_object_id RENAME TO ix_tag_object_id")
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    raise NotImplementedError("These no downgrade defined for this migration")
